' LPDA.BAS  von W.Rolke  Version 1.02

DEFDBL A-Z      ' Alle Variablenbezeichner in doppelter Genauigkeit
		' # : doppeltgenaue Typen
		' % : Integer-Typen

DO
  CLS
  PRINT
  PRINT " ͻ  "
  PRINT "    Dimensionierung einer logarithmisch-periodischen Dipol-Antenne (LPDA)  Ŀ"
  PRINT "                             von W.Rolke   V1.02                            "
  PRINT " ͼ "
  PRINT "   "
  PRINT

  DO
    INPUT " untere Frequenzgrenze fu / MHz "; fu
    INPUT " obere Frequenzgrenze fo / MHz "; fo
  LOOP UNTIL fu < fo AND fu >= 10 AND fo / fu < 50

  DO
    INPUT " Stufungsfaktor (0.8    0.975) "; Tau
  LOOP UNTIL Tau >= .8# AND Tau <= .975#

  OptSigma = .25# * Tau - .058#
  PRINT USING " Maximaler Gewinn mit =#.###"; OptSigma

  DO
    INPUT " elektrische Periodizitt (0.1    0.2) "; Sigma
  LOOP UNTIL Sigma >= .1# AND Sigma <= .2#

  DO
    INPUT " Schlankheitsgrad der Dipole L/d "; s
  LOOP UNTIL s >= 10 AND s <= 10000!

  DO
    INPUT " Resistanz der Speiseleitung Ro /  "; Ro
  LOOP UNTIL Ro >= 30 AND Ro < 600

  DO
    INPUT " Querschnitt der Doppelleitung rund oder quadratisch (r/q) "; Quer$
    Quer$ = UCASE$(Quer$)
  LOOP UNTIL Quer$ = "R" OR Quer$ = "Q"

  IF Quer$ = "R" THEN
     Korrektur = 0
     DO
       INPUT " Durchmesser der Doppelleitung  / mm "; dDoppel
     LOOP UNTIL dDoppel > 0 AND dDoppel <= 50
  ELSE
     Korrektur = 15
     DO
       INPUT " Kantenlnge der Doppelleitung a / mm "; dDoppel
     LOOP UNTIL dDoppel > 0 AND dDoppel <= 50
  END IF

  DO
    INPUT " Aktive Zone schmal oder breit (s/b) "; Breite$
    Breite$ = UCASE$(Breite$)
  LOOP UNTIL Breite$ = "S" OR Breite$ = "B"

  AKBreit = 0
  IF Breite$ = "B" THEN AKBreit = 1

  Pi = 4 * ATN(1)
  LambdaMax = 300 / fu
  AlphaInRad = ATN((1 - Tau) / 4 / Sigma)                'ffnungshalbwinkel
  Alpha = AlphaInRad * 180 / Pi                          'Winkel in Grad
  B = fo / fu                                            'Mindestbandbreite
  K1 = .9725# - .477# * Tau
  K2 = 7.1# * Tau ^ 3 - 21.3# * Tau ^ 2 + 21.98# * Tau - 7.3# + Sigma * (21.82# - 66# * Tau + 62.12# * Tau ^ 2 - 18.29# * Tau ^ 3)
  IF AKBreit THEN                                        'Aktive Zone
    BAktiv = K1 / K2
  ELSE
    BAktiv = 1.1# + 30.8# * (1 - Tau) * Sigma
  END IF
  Elemente = 1 + LOG(B * BAktiv) / LOG(1 / Tau)          'Anzahl der Elemente
  N% = INT(Elemente) + 1                                 'Elemente aufrunden
  BStruktur = (1 / Tau) ^ (N% - 1)                       'Strukturbandbreite
  Beff = BStruktur / BAktiv                              'Effektive Bandbreite
  DIM l(N%), d(N%), a(N%)
  IF AKBreit THEN                                        'Lngstes Element
    l1 = LambdaMax / 2 * K1
  ELSE
    l1 = LambdaMax / 4
  END IF
  Lang = l1 * (1 - 1 / BStruktur) / TAN(AlphaInRad)      'Antennenbaulnge
  l(1) = l1 * 1000                                       'Lngstes Element (mm)
  d(1) = 4 * l(1) * Sigma                                'grter Dipolabstand
  a(1) = 2 * l(1) / s                                    'grter Durchmesser
  FOR i% = 2 TO N%
    l(i%) = l(i% - 1) * Tau                              'Lnge der Elemente
    d(i%) = d(i% - 1) * Tau                              'Dipolabstnde
    a(i%) = 2 * l(i%) / s                                'Elementdurchmesser
  NEXT i%
  ZDipol = 120 * (LOG(s) - 2.25#)                        'Impedanz der Elemente
  Hilf = Ro * SQR(Tau) / Sigma / 8 / ZDipol
  Zo = Ro * (Hilf + SQR(Hilf ^ 2 + 1))                   'Impedanz der Leitung
  h = dDoppel * (EXP((Zo + Korrektur) / 120) + EXP(-(Zo + Korrektur) / 120)) / 2

  CLS
  PRINT " Die wichtigsten Werte der LPDA:"
  PRINT
  PRINT USING " Stufungsfaktor                        =###.###"; Tau
  PRINT USING " elektische Periodizitt               =###.###"; Sigma
  PRINT USING " untere Frequenzgrenze                fu=#####.#MHz"; fu
  PRINT USING " obere Frequenzgrenze                 fo=#####.#MHz"; fu * Beff
  PRINT USING " effektive Bandbreite                  B=####.##"; Beff
  PRINT USING " Strukturbandbreite                   Bs=####.##"; BStruktur
  PRINT USING " Bandbreite der aktiven Zone          Ba=####.##"; BAktiv
  PRINT USING " ffnungshalbwinkel der Struktur       =####.#"; Alpha
  PRINT USING " Erforderliche Dipolanzahl             N=#######"; N%
  PRINT USING " Antennenbaulnge (ohne Stub)          A=###.##m"; Lang
  PRINT USING " Antennenbaulnge (mit Stub)           A=###.##m"; Lang + LambdaMax / 10
  PRINT USING " Lnge der kleinsten Dipolhlfte     l##=#####mm"; N%; l(N%) * s / (1 + s) * .96#
  PRINT USING " Lnge der grten Dipolhlfte        l1=#####mm"; l(1) * s / (1 + s) * .96#
  PRINT USING " kleinster Dipolabstand              d##=#####mm"; N% - 1; d(N% - 1)
  PRINT USING " grter Dipolabstand                 d1=#####mm"; d(1)
  PRINT USING " kleinster Dipoldurchmesser          a##=###.#mm"; N%; a(N%)
  PRINT USING " grter Dipoldurchmesser             a1=###.#mm"; a(1)
  PRINT USING " Mittenabstand der Doppelleitung       s=###.#mm"; h
  PRINT USING " Wellenwiderstand der Dipole          Za=####.#"; ZDipol
  PRINT USING " Wellenwiderstand der Doppelleitung   Zo=####.#"; Zo
  PRINT
  INPUT " Antennenparameter ndern (j/n)"; NeueParam$
  NeueParam$ = UCASE$(NeueParam$)
  IF NeueParam$ = "N" THEN EXIT DO
  ERASE l, d, a
LOOP

CLS
PRINT
PRINT " ͻ"
PRINT "   Dipol     Lnge     Abstand    Durchmesser  "
PRINT " Ķ"
PRINT USING "     1     ##### mm       0 mm    ####.# mm    "; l(1) * s / (1 + s) * .96#; a(1)
FOR i% = 2 TO N%
  PRINT USING "    ##     ##### mm   ##### mm    ####.# mm    "; i%; l(i%) * s / (1 + s) * .96#; d(i% - 1); a(i%)
  IF i% = 18 OR i% = 40 THEN
    PRINT "         Mit beliebiger Taste weiter...           "
    WHILE INKEY$ = "": WEND
  END IF
NEXT i%
PRINT " ͼ"
ERASE l, d, a

